/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { HeaderE2EComponent } from '../../../page-objects/header.po';
import { LoginPage } from '../../../page-objects/login.po';
import { MainPage } from '../../../page-objects/main.po';
import { reload } from '../../../support/cypress-helper';
import { exist } from '../../../support/cypress.util';
import { loginByUi } from '../../../support/user-util';

describe('Login and Logout', () => {
  const loginPage: LoginPage = new LoginPage();
  const mainPage: MainPage = new MainPage();
  const header: HeaderE2EComponent = mainPage.getHeader();

  it('should display accessibility link', () => {
    cy.visit('');
    exist(loginPage.getBarrierefreiheitLink());
  });

  it('login as Ariane', () => {
    Cypress.session.clearAllSavedSessions();

    cy.fixture('user/user_ariane.json').then((user) => {
      loginByUi(user);
    });
  });

  it('should display logo', () => {
    exist(header.getLogo());
  });

  it('should keep user logged in on reload page', () => {
    reload();
    exist(header.getLogo());
  });

  it('should logout', () => {
    header.getCurrentUserProfile().logout();

    exist(loginPage.getLogin());

    Cypress.session.clearAllSavedSessions();
  });
});
