import { faker } from '@faker-js/faker';
import { BenutzerE2EComponent } from 'apps/admin-e2e/src/components/benutzer/benutzer.e2e.component';
import { E2EBenutzerHelper } from 'apps/admin-e2e/src/helper/benutzer/benutzer.helper';
import { E2EBenutzerVerifier } from 'apps/admin-e2e/src/helper/benutzer/benutzer.verifier';
import { AdminUserE2E } from 'apps/admin-e2e/src/model/util';
import { loginAsAriane } from 'apps/admin-e2e/src/support/user-util';

describe('Benutzer Bearbeiten', () => {
  const benutzerVerifier: E2EBenutzerVerifier = new E2EBenutzerVerifier();
  const benutzerHelper: E2EBenutzerHelper = new E2EBenutzerHelper();
  const benutzerPage: BenutzerE2EComponent = new BenutzerE2EComponent();

  const userName: string = 'testtheo' + faker.string.uuid();
  const user: AdminUserE2E = {
    vorname: 'Theo',
    nachname: 'Testuser',
    username: userName,
    email: 'theo' + faker.string.uuid() + '@ozg-sh.de',
    isUser: true,
    organisationseinheiten: [],
  };

  before(() => {
    loginAsAriane();
  });

  it('should add new user', () => {
    benutzerHelper.openNewBenutzerPage();
    benutzerHelper.addBenutzerAndSave(user);
  });

  it('should not be able to edit username', () => {
    benutzerHelper.openBenutzerPage(userName);

    benutzerPage.getBenutzernameInput().should('not.exist');
  });

  it('should deactivate other alfa roles if "user" role is selected', () => {
    benutzerVerifier.verifyAlfaRolesCorrectlyChecked(user);
  });

  it('should edit user', () => {
    const editedUser: AdminUserE2E = { ...user, vorname: 'Theodor' };

    benutzerHelper.editBenutzerAndSave(editedUser);
  });

  it('should check for new user name', () => {
    benutzerHelper.openBenutzerPage(userName);

    benutzerVerifier.verifyUserVorname('Theodor');
  });

  it('should delete user', () => {
    benutzerHelper.deleteBenutzer(userName);
    benutzerVerifier.verifyUserNotInList(userName);
  });
});
