/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { NavigationE2EComponent } from 'apps/alfa-e2e/src/components/navigation/navigation.e2e.component';
import { VorgangListE2EComponent } from 'apps/alfa-e2e/src/components/vorgang/vorgang-list.e2e.component';
import { VorgangViewsE2EComponent } from 'apps/alfa-e2e/src/components/vorgang/vorgang-views.e2e.component';
import { MainPage, waitForSpinnerToDisappear } from 'apps/alfa-e2e/src/page-objects/main.po';
import { dropCollections } from 'apps/alfa-e2e/src/support/cypress-helper';
import { exist, notExist } from 'apps/alfa-e2e/src/support/cypress.util';
import { loginAsEmil } from 'apps/alfa-e2e/src/support/user-util';

describe('Navigation', () => {
  const mainPage: MainPage = new MainPage();
  const vorgangList: VorgangListE2EComponent = mainPage.getVorgangList();
  const vorgangViews: VorgangViewsE2EComponent = mainPage.getViews();

  const navigation: NavigationE2EComponent = mainPage.getNavigation();

  before(() => {
    loginAsEmil();
  });

  after(() => {
    dropCollections();
  });

  describe('after login', () => {
    it('should show vorgangList', { defaultCommandTimeout: 30000 }, () => {
      waitForSpinnerToDisappear();
      exist(vorgangList.getRoot());
    });

    it('should show vorgangList view', () => {
      exist(vorgangViews.getVorgangList().getRoot());
    });
  });

  describe('Vorgang filter', () => {
    it('MeineVorgaenge should NOT exists', () => {
      notExist(navigation.getMeineVorgaengeFilter());
    });

    it('Alle should NOT exists', () => {
      notExist(navigation.getAlleFilter());
    });
  });
});
