/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { HttpMethodE2E, MessageCodeE2E } from 'apps/alfa-e2e/src/model/util';
import { KommentareInVorgangE2EComponent } from '../../../components/kommentar/kommentar-list.e2e.component';
import { VorgangListE2EComponent } from '../../../components/vorgang/vorgang-list.e2e.component';
import { KommentarE2E } from '../../../model/kommentar';
import { VorgangE2E } from '../../../model/vorgang';
import { MainPage, waitForSpinnerToDisappear } from '../../../page-objects/main.po';
import { VorgangPage } from '../../../page-objects/vorgang.po';
import {
  dropCollections,
  interceptWithResponse,
  scrollToWindowBottom,
  waitOfInterceptor,
} from '../../../support/cypress-helper';
import { exist, notExist } from '../../../support/cypress.util';
import { createKommentar } from '../../../support/kommentar.util';
import { loginAsSabine } from '../../../support/user-util';
import { createVorgang, initVorgang } from '../../../support/vorgang-util';

// TODO Deaktiviert, weil die beiden Testfälle in user-profile-icon-in-postfach-nachricht-error.e2e-spec.ts abgedeckt sind.
// Zudem funktioniert der Test seit OZG-1523 so nicht länger.
describe.skip('Kommentar user profile backend error', () => {
  const mainPage: MainPage = new MainPage();
  const vorgangList: VorgangListE2EComponent = mainPage.getVorgangList();

  const vorgangPage: VorgangPage = new VorgangPage();
  const kommentarContainer: KommentareInVorgangE2EComponent = vorgangPage.getKommentarContainer();

  const kommentar: KommentarE2E = { ...createKommentar(), createdBy: 'idNotExist' };
  const vorgang: VorgangE2E = { ...createVorgang(), kommentars: [kommentar] };

  before(() => {
    initVorgang(vorgang);

    loginAsSabine();

    exist(vorgangList.getRoot());
  });

  after(() => {
    dropCollections();
  });

  describe('on status 404', () => {
    let kommentarToExist;

    it('should navigate to vorgang detail', () => {
      vorgangList.getListItem(vorgang.name).getRoot().click();

      exist(vorgangPage.getVorgangDetailHeader().getRoot());
      waitForSpinnerToDisappear();
    });

    it('should show kommentar', () => {
      scrollToWindowBottom();

      kommentarToExist = kommentarContainer.getKommentar(kommentar.text);

      exist(kommentarToExist.getRoot());
    });

    it('should show error not found icon', () => {
      exist(kommentarToExist.getUserProfile().getIconContainer().getErrorResourceNotFoundIcon());
    });

    it('should hide user profile name', () => {
      notExist(kommentarToExist.getUserProfile().getName());
    });

    it('should navigate back to list', () => {
      vorgangPage.getSubnavigation().getBackButton().click();
    });
  });

  describe('on status 503', () => {
    const statusCode: number = 503;
    const getUserProfileInterceptor: string = 'getUserProfileInterceptor';

    let kommentarToExist;

    beforeEach(() => {
      interceptWithResponse(HttpMethodE2E.GET, '/api/userProfiles/*', {
        statusCode,
        body: { issues: [{ messageCode: MessageCodeE2E.SERVICE_UNAVAILABLE }] },
      }).as(getUserProfileInterceptor);
    });

    it('should show vorgang detail after click on vorgang', () => {
      waitForSpinnerToDisappear();
      vorgangList.getListItem(vorgang.name).getRoot().click();

      waitOfInterceptor(getUserProfileInterceptor).then((interception) => {
        assert(interception.response.statusCode, statusCode.toString());
        exist(vorgangPage.getVorgangDetailHeader().getRoot());
        waitForSpinnerToDisappear();
      });
    });

    it('should show kommentar', () => {
      scrollToWindowBottom();

      kommentarToExist = kommentarContainer.getKommentar(kommentar.text);

      exist(kommentarToExist.getRoot());
    });

    it('should show error service unavailable icon', () => {
      scrollToWindowBottom();

      exist(kommentarToExist.getUserProfile().getIconContainer().getErrorServiceUnavailableIcon());
    });

    it('should hide user profile name', () => {
      notExist(kommentarToExist.getUserProfile().getName());
    });

    it('should navigate back', () => {
      vorgangPage.getSubnavigation().getBackButton().click();
    });
  });
});
