/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { faker } from '@faker-js/faker';
import { KommentarInVorgangE2EComponent } from 'apps/alfa-e2e/src/components/kommentar/kommentar-list.e2e.component';
import { PostfachMailListItem } from 'apps/alfa-e2e/src/components/postfach/postfach-mail.e2e.component';
import { VorgangDetailHeaderE2EComponent } from 'apps/alfa-e2e/src/components/vorgang/vorgang-detail-header.e2e.component';
import { VorgangListItemE2EComponent } from 'apps/alfa-e2e/src/components/vorgang/vorgang-item.e2e.component';
import { VorgangListE2EComponent } from 'apps/alfa-e2e/src/components/vorgang/vorgang-list.e2e.component';
import {
  VorgangSearchE2EComponent,
  VorgangSearchPreviewListItemE2EComponent,
} from 'apps/alfa-e2e/src/components/vorgang/vorgang-search.e2e.component';
import { WiedervorlageInVorgangE2EComponent } from 'apps/alfa-e2e/src/components/wiedervorlage/wiedervorlage-in-vorgang.e2e.component';
import { KommentarE2E } from 'apps/alfa-e2e/src/model/kommentar';
import { UserE2E } from 'apps/alfa-e2e/src/model/user';
import { EingangE2E, VorgangE2E, VorgangStatusE2E } from 'apps/alfa-e2e/src/model/vorgang';
import { PostfachMailItemE2E, VorgangAttachedItemE2E } from 'apps/alfa-e2e/src/model/vorgang-attached-item';
import { WiedervorlageE2E } from 'apps/alfa-e2e/src/model/wiedervorlage';
import { HeaderE2EComponent } from 'apps/alfa-e2e/src/page-objects/header.po';
import { VorgangPage } from 'apps/alfa-e2e/src/page-objects/vorgang.po';
import { dropCollections, dropSearchIndex, wait } from 'apps/alfa-e2e/src/support/cypress-helper';
import { createKommentar, createKommentarAttachedItem } from 'apps/alfa-e2e/src/support/kommentar.util';
import {
  createPostfachNachrichtAttachedItem,
  createPostfachNachrichtReplyItem,
} from 'apps/alfa-e2e/src/support/postfach-nachricht.util';
import { initVorgangAttachedItem } from 'apps/alfa-e2e/src/support/vorgang-attached-item-util';
import {
  AntragstellerE2ETestData,
  EingangE2ETestData,
  EingangHeaderE2ETestData,
  buildVorgang,
  createVorgang,
  initSearchIndex,
  initVorgaenge,
  objectIds,
} from 'apps/alfa-e2e/src/support/vorgang-util';
import { createWiedervorlageAttachedItem, createWiedervorlageItem } from 'apps/alfa-e2e/src/support/wiedervorlage-util';
import { MainPage, waitForSpinnerToDisappear } from '../../../page-objects/main.po';
import { backspaceOn, exist, haveText, haveValue, notExist } from '../../../support/cypress.util';
import { UserRoleE2E, getUserSabine, getUserSabineId, initUsermanagerUsers, loginAsSabine } from '../../../support/user-util';

describe('VorgangList Suche', () => {
  const mainPage: MainPage = new MainPage();

  const header: HeaderE2EComponent = mainPage.getHeader();
  const vorgangSearch: VorgangSearchE2EComponent = header.getVorgangSearch();

  const vorgangList: VorgangListE2EComponent = mainPage.getVorgangList();

  const vorgangPage: VorgangPage = new VorgangPage();
  const vorgangHeader: VorgangDetailHeaderE2EComponent = vorgangPage.getVorgangDetailHeader();

  describe(`on user with role ${UserRoleE2E.VERWALTUNG_USER} by requestId/Eingangskennzeichen`, () => {
    const requestId: string = faker.string.uuid();
    const eingang: EingangE2E = {
      ...EingangE2ETestData,
      header: { ...EingangHeaderE2ETestData, requestId },
    };
    const vorgangToStay: VorgangE2E = {
      ...createVorgang(),
      name: 'VorgangToStay',
      eingangs: [eingang],
      assignedTo: getUserSabineId(),
    };

    const vorgangToDisappear: VorgangE2E = {
      ...buildVorgang(objectIds[0], 'VorgangToDisappear'),
      status: VorgangStatusE2E.NEU,
    };
    const vorgangHyphen: VorgangE2E = {
      ...buildVorgang(objectIds[1], 'Vorgang-mit-Bindestrich'),
      status: VorgangStatusE2E.NEU,
    };
    const vorgangWOHyphen: VorgangE2E = {
      ...buildVorgang(objectIds[2], 'Vorgang mit Leerzeichen'),
      status: VorgangStatusE2E.NEU,
    };

    const vorgangStayInList: VorgangListItemE2EComponent = vorgangList.getListItem(vorgangToStay.name);
    const vorgangDisappearInList: VorgangListItemE2EComponent = vorgangList.getListItem(vorgangToDisappear.name);
    const vorgangHyphenInList: VorgangListItemE2EComponent = vorgangList.getListItem(vorgangHyphen.name);
    const vorgangWOHyphenInList: VorgangListItemE2EComponent = vorgangList.getListItem(vorgangWOHyphen.name);

    const userSabine: UserE2E = getUserSabine();

    before(() => {
      initVorgaenge([vorgangToStay, vorgangToDisappear, vorgangHyphen, vorgangWOHyphen]);
      initSearchIndex([vorgangToStay, vorgangToDisappear, vorgangHyphen, vorgangWOHyphen]);
      initUsermanagerUsers();

      loginAsSabine();

      waitForSpinnerToDisappear();
      exist(vorgangList.getRoot());
    });

    after(() => {
      dropCollections();
      dropSearchIndex();
    });

    it('should filter list', () => {
      doSearchWith(vorgangToStay.name);
      waitForSpinnerToDisappear();

      //TODO: Schlägt beim ersten Versuch immer fehl, es wird kein Enter ausgeführt
      exist(vorgangStayInList.getRoot());
      notExist(vorgangDisappearInList.getRoot());
    });

    describe('Search for partial strings...', () => {
      it('should find partial string at the beginning', () => {
        doSearchWith('VorgangToS');
        waitForSpinnerToDisappear();

        exist(vorgangStayInList.getRoot());
      });

      it('should find partial string in the middle', () => {
        doSearchWith('gangToSt');
        waitForSpinnerToDisappear();

        exist(vorgangStayInList.getRoot());
      });

      it('should find partial string at the end, case insensitive', () => {
        doSearchWith('toStay');
        waitForSpinnerToDisappear();

        exist(vorgangStayInList.getRoot());
      });
    });

    describe('Search with hyphen', () => {
      it('should find entry with hyphen', () => {
        doSearchWith('Vorgang-mit');
        waitForSpinnerToDisappear();

        //TODO: FixMe - findet auf Jenkins keine Ergebnisse bei dieser Suche
        //exist(vorgangHyphenInList.getRoot());
        //notExist(vorgangWOHyphenInList.getRoot());
      });

      it('should find entry without hyphen', () => {
        doSearchWith('Vorgang mit');
        waitForSpinnerToDisappear();

        //OZG-5425: wieder aktivieren, wenn gefixt
        //notExist(vorgangHyphenInList.getRoot());
        exist(vorgangWOHyphenInList.getRoot());
      });
    });

    describe('Search using AND operator', () => {
      it('should find entry with all matches', () => {
        doSearchWith('Vorgang mit Leerzeichen');
        waitForSpinnerToDisappear();

        exist(vorgangWOHyphenInList.getRoot());
      });

      it('should not find entry when using additional words', () => {
        doSearchWith('Vorgang mit als Leerzeichen');
        waitForSpinnerToDisappear();

        notExist(vorgangWOHyphenInList.getRoot());
      });
    });

    describe('navigate with filtered list to vorgang detail', () => {
      beforeEach(() => {
        doSearchWith(vorgangToStay.name);
        waitForSpinnerToDisappear();

        exist(vorgangList.getRoot());
        vorgangStayInList.getRoot().click();
        exist(vorgangPage.getVorgangDetailHeader().getRoot());
      });

      describe('and navigate back', () => {
        it('should show filtered list after navigate back to list', () => {
          vorgangPage.getSubnavigation().getBackButton().click();
          waitForSpinnerToDisappear();

          exist(vorgangList.getRoot());
          exist(vorgangStayInList.getRoot());
          notExist(vorgangDisappearInList.getRoot());
        });
      });
    });

    describe('clear search button', () => {
      beforeEach(() => {
        waitForSpinnerToDisappear();
      });

      it('should not be visible if empty search field', () => {
        vorgangSearch.getInput().clear();

        notExist(vorgangSearch.getClearButton());
      });

      it('should be visible if search field contains text', () => {
        vorgangSearch.getInput().clear().type('Gewe');

        exist(vorgangSearch.getClearButton());
      });

      it('should show unfiltered list if clicked', () => {
        doSearchWith(vorgangToStay.name);
        waitForSpinnerToDisappear();

        vorgangSearch.getClearButton().click();
        waitForSpinnerToDisappear();

        exist(vorgangList.getRoot());
        exist(vorgangStayInList.getRoot());
        exist(vorgangDisappearInList.getRoot());
      });
    });

    describe('loading vorgang', () => {
      it('should open vorgang', () => {
        doSearchWith('VorgangTo');
        vorgangStayInList.getRoot().click();

        exist(vorgangPage.getSpinner());
        waitForSpinnerToDisappear();
      });

      it('should navigate back to list', () => {
        vorgangPage.getSubnavigation().getBackButton().click();
        exist(vorgangPage.getSpinner());
        waitForSpinnerToDisappear();

        exist(vorgangList.getRoot());
      });

      it('should open another vorgang', () => {
        vorgangDisappearInList.getRoot().click();
        exist(vorgangPage.getSpinner());
        waitForSpinnerToDisappear();

        exist(vorgangHeader.getRoot());
        exist(vorgangHeader.getUserContainer().getIconContainer().getUnassignedIcon());
      });

      it('should navigate back to list', () => {
        vorgangPage.getSubnavigation().getBackButton().click();

        exist(vorgangList.getRoot());
      });
    });
  });

  describe('filter by preview list', () => {
    const vorgangName: string = 'VorgangMatchBySearch';
    const vorgang: VorgangE2E = { ...createVorgang(), name: vorgangName };

    const wiedervorlageForMatchBySearch: WiedervorlageE2E = {
      ...createWiedervorlageItem('WiedervorlageMatchBySearch'),
      done: false,
    };
    const wiedervorlageAttachedItemForMatchBySearch: VorgangAttachedItemE2E = {
      ...createWiedervorlageAttachedItem(objectIds[0], vorgang._id.$oid),
      item: wiedervorlageForMatchBySearch,
    };

    const kommentarForMatchBySearch: KommentarE2E = {
      ...createKommentar(),
      text: 'KommentarMatchBySearch',
    };
    const kommentarAttachedItemForMatchBySearch: VorgangAttachedItemE2E = {
      ...createKommentarAttachedItem(objectIds[1], vorgang._id.$oid),
      item: kommentarForMatchBySearch,
    };

    const postfachNachrichtForMatchBySearch: PostfachMailItemE2E = {
      ...createPostfachNachrichtReplyItem(),
      createdBy: getUserSabineId(),
      subject: 'PostfachNachrichtForMatchBySearch',
    };

    const postfachNachrichtAttachedItemForMatchBySearch: VorgangAttachedItemE2E = {
      ...createPostfachNachrichtAttachedItem(objectIds[2], vorgang._id.$oid),
      item: postfachNachrichtForMatchBySearch,
    };

    const previewListItemVorgang: VorgangSearchPreviewListItemE2EComponent = vorgangSearch.getVorgangSearchPreviewListItem(
      vorgang.name,
    );

    const vorgangOtherName: string = 'VorgangOther';
    const vorgangOther: VorgangE2E = {
      ...buildVorgang(objectIds[3], vorgangOtherName),
      status: VorgangStatusE2E.NEU,
    };

    const wiedervorlageForOther: WiedervorlageE2E = {
      ...createWiedervorlageItem('WiedervorlageOther'),
      done: true,
    };
    const wiedervorlageAttachedItemForOther: VorgangAttachedItemE2E = {
      ...createWiedervorlageAttachedItem(objectIds[4], vorgangOther._id.$oid),
      item: wiedervorlageForOther,
    };

    const kommentarForOther: KommentarE2E = { ...createKommentar(), text: 'KommentarOther' };
    const kommentarAttachedItemForOther: VorgangAttachedItemE2E = {
      ...createKommentarAttachedItem(objectIds[5], vorgangOther._id.$oid),
      item: kommentarForOther,
    };

    const postfachNachrichtForOther: PostfachMailItemE2E = {
      ...createPostfachNachrichtReplyItem(),
      createdBy: getUserSabineId(),
      subject: 'PostfachNachrichtOther',
    };

    const postfachNachrichtAttachedItemForOther: VorgangAttachedItemE2E = {
      ...createPostfachNachrichtAttachedItem(objectIds[6], vorgangOther._id.$oid),
      item: postfachNachrichtForOther,
    };

    const previewListItemVorgangOther: VorgangSearchPreviewListItemE2EComponent = vorgangSearch.getVorgangSearchPreviewListItem(
      vorgangOther.name,
    );

    before(() => {
      initVorgaenge([vorgang, vorgangOther]);
      initVorgangAttachedItem([
        wiedervorlageAttachedItemForMatchBySearch,
        wiedervorlageAttachedItemForOther,
        kommentarAttachedItemForMatchBySearch,
        kommentarAttachedItemForOther,
        postfachNachrichtAttachedItemForMatchBySearch,
        postfachNachrichtAttachedItemForOther,
      ]);
      initSearchIndex([vorgang, vorgangOther]);

      loginAsSabine();

      waitForSpinnerToDisappear();
      exist(vorgangList.getRoot());
    });

    after(() => {
      dropCollections();
      dropSearchIndex();
    });

    it('should NOT show preview list initial', () => {
      notExist(vorgangSearch.getVorgangSearchPreviewList());
    });

    it('should NOT show preview list on 2 character', () => {
      vorgangSearch.getInput().clear().type(vorgangName.substring(0, 2));

      notExist(vorgangSearch.getVorgangSearchPreviewList());
    });

    it('should show content of preview list on 3 character', () => {
      vorgangSearch.getInput().clear().type(vorgangName.substring(0, 3));

      exist(previewListItemVorgang.getRoot());
      exist(previewListItemVorgangOther.getRoot());
    });

    it('should list item informations', () => {
      vorgangSearch.getInput().clear().type(vorgangName);

      exist(previewListItemVorgang.getRoot());
      exist(previewListItemVorgang.getCreatedAt());
      exist(previewListItemVorgang.getVorgangName());
      exist(previewListItemVorgang.getVorgangAktenzeichen());
      exist(previewListItemVorgang.getVorgangNummer());
    });

    describe('select vorgang in vorganglist preview list', () => {
      it('should navigate to vorgang on selection', () => {
        vorgangSearch.getInput().clear().type(vorgangName);
        exist(previewListItemVorgang.getRoot());

        previewListItemVorgang.getRoot().click();

        exist(vorgangPage.getVorgangDetailHeader().getRoot());
        haveText(vorgangPage.getVorgangDetailHeader().getName(), vorgangName);
      });
    });

    describe('select vorgang in vorgangdetail preview list', () => {
      it('should navigate to vorgang on selection', () => {
        vorgangSearch.getInput().clear().type(vorgangOtherName);
        waitForSpinnerToDisappear();
        exist(previewListItemVorgangOther.getRoot());

        previewListItemVorgangOther.getRoot().click();

        exist(vorgangPage.getVorgangDetailHeader().getRoot());
        haveText(vorgangPage.getVorgangDetailHeader().getName(), vorgangOtherName);
      });

      it('should have wiedervorlage', () => {
        const wiedervorlage: WiedervorlageInVorgangE2EComponent = vorgangPage
          .getWiedervorlagenContainer()
          .getWiedervorlage('WiedervorlageOther');

        exist(wiedervorlage.getRoot());
      });

      it('should have kommentar', () => {
        const kommentar: KommentarInVorgangE2EComponent = vorgangPage.getKommentarContainer().getKommentar('KommentarOther');

        exist(kommentar.getRoot());
      });

      it('should have postfachNachricht', () => {
        const postfachNachricht: PostfachMailListItem = vorgangPage
          .getPostfachMailcontainer()
          .getListItem('PostfachNachrichtOther');

        exist(postfachNachricht.getRoot());
      });
    });

    describe('clear preview list if clicking clear button', () => {
      it('should hide preview list', () => {
        vorgangSearch.getInput().clear().type(vorgangName.substring(0, 3));

        exist(previewListItemVorgang.getRoot());
        exist(previewListItemVorgangOther.getRoot());

        vorgangSearch.getClearButton().click();
        waitForSpinnerToDisappear();

        notExist(vorgangSearch.getVorgangSearchPreviewList());
      });
    });

    describe('clear preview list on less than 3 character', () => {
      it('should hide preview list', () => {
        wait(1000);
        vorgangSearch.getInput().clear().type(vorgangName.substring(0, 3), { delay: 220 });

        exist(previewListItemVorgang.getRoot());
        exist(previewListItemVorgangOther.getRoot());

        backspaceOn(vorgangSearch.getInput());

        notExist(vorgangSearch.getVorgangSearchPreviewList());
      });
    });
  });

  describe('filter by all possible fields', () => {
    const NO_MATCH: string = 'no match';

    const vorgangNameToMatch: string = 'VorgangStayByVorgangName';
    const eingangByVorgangName: EingangE2E = {
      ...EingangE2ETestData,
      antragsteller: { ...AntragstellerE2ETestData, vorname: NO_MATCH, nachname: NO_MATCH },
      header: { ...EingangHeaderE2ETestData, requestId: NO_MATCH },
    };
    const vorgangStayByVorgangName: VorgangE2E = {
      ...buildVorgang(objectIds[0], vorgangNameToMatch),
      aktenzeichen: NO_MATCH,
      eingangs: [eingangByVorgangName],
    };

    const aktenzeichenToMatch: string = 'Ein Aktenzeichen';
    const eingangByAktenzeichen: EingangE2E = {
      ...EingangE2ETestData,
      antragsteller: { ...AntragstellerE2ETestData, vorname: NO_MATCH, nachname: NO_MATCH },
      header: { ...EingangHeaderE2ETestData, requestId: NO_MATCH },
    };
    const vorgangStayByAktenzeichen: VorgangE2E = {
      ...createVorgang(),
      name: 'VorgangStayByAktenzeichen',
      aktenzeichen: aktenzeichenToMatch,
      eingangs: [eingangByAktenzeichen],
    };

    const antragstellerVornameToMatch: string = 'Vorname vom Antragsteller';
    const eingangByAntragstellerVorname: EingangE2E = {
      ...EingangE2ETestData,
      antragsteller: {
        ...AntragstellerE2ETestData,
        vorname: antragstellerVornameToMatch,
        nachname: NO_MATCH,
      },
      header: { ...EingangHeaderE2ETestData, requestId: NO_MATCH },
    };
    const vorgangStayByAntragstellerVorname: VorgangE2E = {
      ...buildVorgang(objectIds[1], 'VorgangStayByAntragstellerVorname'),
      aktenzeichen: NO_MATCH,
      eingangs: [eingangByAntragstellerVorname],
    };

    const antragstellerNachnameToMatch: string = 'Nachname vom Antragsteller';
    const eingangByAntragstellerNachname: EingangE2E = {
      ...EingangE2ETestData,
      antragsteller: {
        ...AntragstellerE2ETestData,
        vorname: NO_MATCH,
        nachname: antragstellerNachnameToMatch,
      },
      header: { ...EingangHeaderE2ETestData, requestId: NO_MATCH },
    };
    const vorgangStayByAntragstellerNachname: VorgangE2E = {
      ...buildVorgang(objectIds[2], 'VorgangStayByAntragstellerNachname'),
      aktenzeichen: NO_MATCH,
      eingangs: [eingangByAntragstellerNachname],
    };

    const vorgangNummerToMatch: string = 'VORGANGNUMMER_EHEMALS_REQUEST_ID';
    const eingangByRequestId: EingangE2E = {
      ...EingangE2ETestData,
      antragsteller: { ...AntragstellerE2ETestData, vorname: NO_MATCH, nachname: NO_MATCH },
    };
    const vorgangStayByRequestId: VorgangE2E = {
      ...buildVorgang(objectIds[3], 'VorgangStayByRequestId'),
      aktenzeichen: NO_MATCH,
      eingangs: [eingangByRequestId],
      nummer: vorgangNummerToMatch,
    };

    before(() => {
      initVorgaenge([
        vorgangStayByVorgangName,
        vorgangStayByAktenzeichen,
        vorgangStayByAntragstellerVorname,
        vorgangStayByAntragstellerNachname,
        vorgangStayByRequestId,
      ]);
      initSearchIndex([
        vorgangStayByVorgangName,
        vorgangStayByAktenzeichen,
        vorgangStayByAntragstellerVorname,
        vorgangStayByAntragstellerNachname,
        vorgangStayByRequestId,
      ]);
    });

    after(() => {
      dropCollections();
      dropSearchIndex();
    });

    describe('do search with field...', () => {
      const byVorgangName: VorgangListItemE2EComponent = vorgangList.getListItem(vorgangStayByVorgangName.name);
      const byAktenzeichen: VorgangListItemE2EComponent = vorgangList.getListItem(vorgangStayByAktenzeichen.name);
      const byAntragstellerVorname: VorgangListItemE2EComponent = vorgangList.getListItem(vorgangStayByAntragstellerVorname.name);
      const byAntragstellerNachname: VorgangListItemE2EComponent = vorgangList.getListItem(
        vorgangStayByAntragstellerNachname.name,
      );
      const byRequestId: VorgangListItemE2EComponent = vorgangList.getListItem(vorgangStayByRequestId.name);

      it('should show result by vorgang name', () => {
        doSearchWith(vorgangNameToMatch);
        waitForSpinnerToDisappear();

        exist(byVorgangName.getRoot());
        notExist(byAktenzeichen.getRoot());
        notExist(byAntragstellerVorname.getRoot());
        notExist(byAntragstellerNachname.getRoot());
        notExist(byRequestId.getRoot());
      });

      it('should show result by aktenzeichen', () => {
        doSearchWith(aktenzeichenToMatch);
        waitForSpinnerToDisappear();

        notExist(byVorgangName.getRoot());
        exist(byAktenzeichen.getRoot());
        notExist(byAntragstellerVorname.getRoot());
        notExist(byAntragstellerNachname.getRoot());
        notExist(byRequestId.getRoot());
      });

      it('should show result by antragsteller vorname', () => {
        doSearchWith(antragstellerVornameToMatch);
        waitForSpinnerToDisappear();

        notExist(byVorgangName.getRoot());
        notExist(byAktenzeichen.getRoot());
        exist(byAntragstellerVorname.getRoot());
        notExist(byAntragstellerNachname.getRoot());
        notExist(byRequestId.getRoot());
      });

      it('should show result by antragsteller nachname', () => {
        doSearchWith(antragstellerNachnameToMatch);
        waitForSpinnerToDisappear();

        notExist(byVorgangName.getRoot());
        notExist(byAktenzeichen.getRoot());
        notExist(byAntragstellerVorname.getRoot());
        exist(byAntragstellerNachname.getRoot());
        notExist(byRequestId.getRoot());
      });

      it('should show result by vorgangnummer', () => {
        doSearchWith(vorgangNummerToMatch);
        waitForSpinnerToDisappear();

        notExist(byVorgangName.getRoot());
        notExist(byAktenzeichen.getRoot());
        notExist(byAntragstellerVorname.getRoot());
        notExist(byAntragstellerNachname.getRoot());
        exist(byRequestId.getRoot());
      });

      it('search button should show search result', () => {
        doSearchWith(vorgangNummerToMatch);
        waitForSpinnerToDisappear();

        notExist(byVorgangName.getRoot());
      });
    });
  });

  describe('leave search field', () => {
    it('without submit should set previously entered text', () => {
      doSearchWith('Gewerbe');

      vorgangSearch.getInput().clear().type('Gewe');
      vorgangList.getRoot().click();

      haveValue(vorgangSearch.getInput(), 'Gewerbe');
    });
  });

  describe('empty search field', () => {
    it('should not search with empty input', () => {
      vorgangSearch.getInput().clear().type('{enter}');

      notExist(vorgangPage.getSpinner());
    });
  });

  function doSearchWith(searchBy: string): void {
    vorgangSearch.doSearch(searchBy);
  }
});
