import { AttachmentContainerE2EComponent, AttachmentE2EItem } from '../../components/attachment/attachment.e2e.component';
import { waitForSpinnerToDisappear } from '../../page-objects/main.po';
import { exist, notExist } from '../../support/cypress.util';
import { uploadEmptyFile, uploadFiles } from '../../support/file-upload';

export class E2EAttachmentExecutor {
  private readonly attachmentContainer: AttachmentContainerE2EComponent = new AttachmentContainerE2EComponent();

  public uploadAttachment(fileNames: string[]): void {
    uploadFiles(this.getUploadInput(), fileNames);
    waitForSpinnerToDisappear();
  }

  public uploadEmptyAttachment(fileName: string): void {
    uploadEmptyFile(this.getUploadInput(), fileName);
    waitForSpinnerToDisappear();
  }

  private getUploadInput(): Cypress.Chainable<HTMLElement> {
    return this.attachmentContainer.getUploadInput();
  }

  public deleteAttachments(fileNames: string[]): void {
    fileNames.forEach((fileName: string) => this.deleteAttachment(fileName));
  }

  private deleteAttachment(fileName: string): void {
    const attachment: AttachmentE2EItem = this.getAttachment(fileName);
    exist(attachment.getRoot());
    attachment.getDeleteButton().click();
    notExist(attachment.getRoot());
  }

  public downloadAttachment(fileName: string): void {
    const attachment: AttachmentE2EItem = this.getAttachment(fileName);
    exist(attachment.getRoot());
    attachment.getDownloadButton().click();
    waitForSpinnerToDisappear();
  }

  private getAttachment(fileName: string): AttachmentE2EItem {
    return this.attachmentContainer.getList().getItem(fileName);
  }
}
