import { VorgangFormularButtonsE2EComponent } from '../../components/vorgang/vorgang-formular-buttons.e2e.components';
import { VorgangListE2EComponent } from '../../components/vorgang/vorgang-list.e2e.component';
import { VorgangStatusE2E, vorgangStatusLabelE2E } from '../../model/vorgang';
import { VorgangPage } from '../../page-objects/vorgang.po';
import { exist, haveText, notExist } from '../../support/cypress.util';

export class E2EVorgangVerifier {
  private readonly vorgangPage: VorgangPage = new VorgangPage();
  private readonly vorgangList: VorgangListE2EComponent = new VorgangListE2EComponent();
  private readonly formularButtons: VorgangFormularButtonsE2EComponent = new VorgangFormularButtonsE2EComponent();

  public verifyStatus(status: VorgangStatusE2E): void {
    haveText(this.vorgangPage.getVorgangDetailHeader().getStatus(), vorgangStatusLabelE2E[status]);
  }

  public verifyStatusInList(vorgangName: string, status: VorgangStatusE2E): void {
    haveText(this.vorgangList.getListItem(vorgangName).getStatus(), vorgangStatusLabelE2E[status]);
  }

  public verifyForwardingButtonExists(): void {
    exist(this.vorgangPage.getFormularButtons().getForwardButton());
  }

  public verifyNoForwardingButtonExists(): void {
    notExist(this.vorgangPage.getFormularButtons().getForwardButton());
  }

  public verifyVorgangIsLocked(): void {
    this.verifyFormularButtonsNotVisible();
    notExist(this.vorgangPage.getWiedervorlagenContainer().getCreateWiedervorlageButton());
    notExist(this.vorgangPage.getKommentarContainer().getHinzufuegenButton());
    notExist(this.vorgangPage.getPostfachMailcontainer().getCreateButtonWithText());
    notExist(this.vorgangPage.getPostfachMailcontainer().getCreateButtonWithoutText());
  }

  private verifyFormularButtonsNotVisible(): void {
    notExist(this.formularButtons.getAbschliessenButton());
    notExist(this.formularButtons.getBearbeitenButton());
    notExist(this.formularButtons.getBescheidenButton());
    notExist(this.formularButtons.getEndgueltigLoeschenButton());
    notExist(this.formularButtons.getForwardButton());
    notExist(this.formularButtons.getLoeschAnforderungZuruecknehmenButton());
    notExist(this.formularButtons.getVerwerfenButton());
    notExist(this.formularButtons.getWiedereroeffnenButton());
    notExist(this.formularButtons.getZurueckholenButton());
    notExist(this.formularButtons.getZurueckstellenButton());
  }
}
