import { ConfigurationLinkRel } from '@admin-client/configuration-shared';
import { createEmptyStateResource, createStateResource, HasLinkPipe } from '@alfa-client/tech-shared';
import { existsAsHtmlElement, notExistsAsHtmlElement } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { MailboxIconComponent, NavItemComponent } from '@ods/system';
import { createConfigurationResource } from 'libs/admin/configuration-shared/test/configuration';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { MockComponent } from 'ng-mocks';
import { MenuComponent } from './menu.component';

describe('MenuComponent', () => {
  let component: MenuComponent;
  let fixture: ComponentFixture<MenuComponent>;

  const postfachNavigation: string = getDataTestIdOf('postfach-navigation');
  const statistikNavigationSelector: string = getDataTestIdOf('statistik-navigation');

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      imports: [MenuComponent, HasLinkPipe],
      declarations: [MockComponent(NavItemComponent), MockComponent(MailboxIconComponent)],
    }).compileComponents();

    fixture = TestBed.createComponent(MenuComponent);
    component = fixture.componentInstance;
    component.configurationStateResource = createEmptyStateResource();
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('postfach navigation', () => {
    it('should show if settings link is present', () => {
      component.configurationStateResource = createStateResource(createConfigurationResource([ConfigurationLinkRel.SETTING]));

      fixture.detectChanges();

      existsAsHtmlElement(fixture, postfachNavigation);
    });

    it('should hide if settings link is missing', () => {
      component.configurationStateResource = createStateResource(createConfigurationResource());

      fixture.detectChanges();

      notExistsAsHtmlElement(fixture, postfachNavigation);
    });
  });

  describe('statistic navigation', () => {
    it('should show if settings link is present', () => {
      component.configurationStateResource = createStateResource(
        createConfigurationResource([ConfigurationLinkRel.AGGREGATION_MAPPINGS]),
      );

      fixture.detectChanges();

      existsAsHtmlElement(fixture, statistikNavigationSelector);
    });

    it('should hide if settings link is missing', () => {
      component.configurationStateResource = createStateResource(createConfigurationResource());

      fixture.detectChanges();

      notExistsAsHtmlElement(fixture, statistikNavigationSelector);
    });
  });
});
