/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { TestBed } from '@angular/core/testing';
import { ApiError, ApiErrorAction } from '@alfa-client/tech-shared';
import { mock } from '@alfa-client/test-utils';
import { provideMockActions } from '@ngrx/effects/testing';
import { Action } from '@ngrx/store';
import { provideMockStore } from '@ngrx/store/testing';
import { cold, hot } from 'jest-marbles';
import { createApiRootResource } from 'libs/api-root-shared/test/api-root';
import { Observable, of } from 'rxjs';
import { createApiError } from '../../../../tech-shared/test/error';
import { ApiRootResource } from '../api-root.model';
import { ApiRootRepository } from '../api-root.repository';
import { ApiRootProps } from './api-root.actions';
import { ApiRootEffects } from './api-root.effects';

import * as ApiRootActions from './api-root.actions';

describe('ApiRootEffects', () => {
  let actions: Observable<Action>;
  let effects: ApiRootEffects;

  const apiRootService = mock(ApiRootRepository);

  beforeEach(() => {
    TestBed.configureTestingModule({
      providers: [
        ApiRootEffects,
        provideMockActions(() => actions),
        provideMockStore(),
        {
          provide: ApiRootRepository,
          useValue: apiRootService,
        },
      ],
    });
    effects = TestBed.inject(ApiRootEffects);
  });

  describe('load', () => {
    const apiRoot: ApiRootResource = createApiRootResource();

    it('should call service', () => {
      actions = of(ApiRootActions.loadApiRoot());

      effects.load$.subscribe();

      expect(apiRootService.loadApiRoot).toHaveBeenCalled();
    });

    it('should dispatch loadApiRootSuccess action', () => {
      apiRootService.loadApiRoot.mockReturnValue(of(apiRoot));

      actions = hot('-a-|', { a: ApiRootActions.loadApiRoot() });

      const expected = hot('-a-|', {
        a: ApiRootActions.loadApiRootSuccess(<ApiRootProps>{ apiRoot }),
      });
      expect(effects.load$).toBeObservable(expected);
    });

    it('should dispatch loadApiRootFailure action', () => {
      const apiError: ApiError = createApiError();
      const errorResponse = cold('-#', {}, apiError);
      apiRootService.loadApiRoot = jest.fn(() => errorResponse);

      const expected = cold('--c', {
        c: ApiRootActions.loadApiRootFailure(<ApiErrorAction>{ apiError }),
      });
      actions = hot('-a', { a: ApiRootActions.loadApiRoot() });

      expect(effects.load$).toBeObservable(expected);
    });
  });
});
