/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { CommandResource } from '@alfa-client/command-shared';
import { createStateResource, StateResource } from '@alfa-client/tech-shared';
import { getElementFromFixtureByType, Mock, mock, triggerEvent, useFromMock } from '@alfa-client/test-utils';
import { EventEmitter } from '@angular/core';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { ButtonWithSpinnerComponent } from '@ods/component';
import { MockComponent } from 'ng-mocks';
import { createCommandResource } from '../../../../../../command-shared/test/command';
import { getDataTestIdAttributeOf } from '../../../../../../tech-shared/test/data-test';
import { BescheidWizardWeiterButtonComponent } from './bescheid-wizard-weiter-button.component';

describe('BescheidWizardWeiterButtonComponent', () => {
  let component: BescheidWizardWeiterButtonComponent;
  let fixture: ComponentFixture<BescheidWizardWeiterButtonComponent>;

  const button: string = getDataTestIdAttributeOf('bescheid-weiter-button');

  let clickEmitter: Mock<EventEmitter<MouseEvent>>;

  beforeEach(() => {
    clickEmitter = mock(EventEmitter);
  });

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [BescheidWizardWeiterButtonComponent, MockComponent(ButtonWithSpinnerComponent)],
    }).compileComponents();

    fixture = TestBed.createComponent(BescheidWizardWeiterButtonComponent);
    component = fixture.componentInstance;
    component.clickEmitter = useFromMock(clickEmitter);
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('template', () => {
    describe('ods-button-with-spinner', () => {
      describe('input', () => {
        it('should set submitStateResource', () => {
          const stateResource: StateResource<CommandResource> = createStateResource(createCommandResource(), true);
          component.submitStateResource = stateResource;

          fixture.detectChanges();

          expect(getElementFromFixtureByType(fixture, ButtonWithSpinnerComponent).stateResource).toEqual(stateResource);
        });
      });

      describe('output', () => {
        it('should emit click', () => {
          triggerEvent({
            fixture,
            name: 'clickEmitter',
            elementSelector: button,
          });

          expect(clickEmitter.emit).toHaveBeenCalled();
        });
      });
    });
  });
});
