/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { StateResource, createEmptyStateResource } from '@alfa-client/tech-shared';
import { createCreateCommand } from 'libs/command-shared/test/command';
import { CommandOrder, CommandResource, CreateCommand } from '../command.model';
import { CommandPartialState, initialState } from './command.reducer';

import * as Selectors from './command.selectors';

describe('Command Selectors', () => {
  let state: CommandPartialState;

  const commandInState: CreateCommand = createCreateCommand();
  const commandInStateOrder: CommandOrder = CommandOrder.VORGANG_ANNEHMEN;
  const commandByOrderMap: any = { [commandInStateOrder]: commandInState };

  beforeEach(() => {
    state = {
      CommandState: {
        ...initialState,
        commandByOrderMap,
      },
    };
  });

  describe('commandByOrderMap', () => {
    it('should select commandByOrderMap', () => {
      const result: any = Selectors.commandByOrderMap.projector(state.CommandState);

      expect(result).toBe(commandByOrderMap);
    });
  });

  describe('commandByOrder', () => {
    it('should return command from map by order', () => {
      const result: StateResource<CommandResource> =
        Selectors.commandByOrder(commandInStateOrder).projector(commandByOrderMap);

      expect(result).toBe(commandInState);
    });

    it('should return empty state resource on empty object', () => {
      const result: StateResource<CommandResource> = Selectors.commandByOrder(
        commandInStateOrder,
      ).projector({});

      expect(result).toEqual(createEmptyStateResource());
    });
  });
});
