/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { FormControl } from '@angular/forms';
import { argsToTemplate, moduleMetadata, type Meta, type StoryObj } from '@storybook/angular';
import { CheckboxComponent } from './checkbox.component';

const formControlWithError = new FormControl(false);
formControlWithError.setErrors({ error: 404 });

const meta: Meta<CheckboxComponent> = {
  title: 'Checkbox',
  component: CheckboxComponent,
  decorators: [
    moduleMetadata({
      imports: [CheckboxComponent],
    }),
  ],
  excludeStories: /.*Data$/,
  tags: ['autodocs'],
};

export default meta;
type Story = StoryObj<CheckboxComponent>;

export const Default: Story = {
  args: {
    label: 'Basic checkbox',
    inputId: '1',
    disabled: false,
    hasError: false,
  },
  argTypes: {
    label: { description: 'Checkbox label' },
    disabled: { description: 'Disabled state of checkbox' },
    inputId: { description: 'Id of checkbox input' },
    hasError: { description: 'Has checkbox the error state' },
    fieldControl: {
      description: 'Form control object',
      table: { type: { summary: 'FormControl' } },
    },
  },
};

export const Error: Story = {
  args: {
    label: 'Checkbox with error state',
    inputId: '2',
    hasError: true,
  },
};

export const Disabled: Story = {
  args: {
    label: 'Disabled checkbox',
    inputId: '3',
    disabled: true,
  },
};

export const MultiLineLabel: Story = {
  args: {
    label: 'Very long label that should break',
    inputId: '4',
  },
  render: (args) => ({
    props: args,
    template: `<div class="w-40"><ods-checkbox ${argsToTemplate(args)}/></div>`,
  }),
};
