/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { argsToTemplate, moduleMetadata, type Meta, type StoryObj } from '@storybook/angular';

import { ButtonComponent } from '../button/button.component';
import { ForwardingItemInfoComponent } from './forwarding-item-info/forwarding-item-info.component';
import { ForwardingDirection, ForwardingItemComponent } from './forwarding-item.component';

const meta: Meta<ForwardingItemComponent> = {
  title: 'Forwarding item',
  component: ForwardingItemComponent,
  parameters: {
    docs: {
      description: {
        component: 'Information of forwarded item',
      },
    },
  },
  decorators: [
    moduleMetadata({
      imports: [ForwardingItemComponent, ForwardingItemInfoComponent, ButtonComponent],
    }),
  ],
  excludeStories: /.*Data$/,
  tags: ['autodocs'],
};

export default meta;
type Story = StoryObj<ForwardingItemComponent>;

export const Default: Story = {
  args: {
    direction: ForwardingDirection.TO,
  },
  argTypes: {
    direction: { control: 'select', options: [ForwardingDirection.TO, ForwardingDirection.FROM] },
  },
  render: () => ({
    template: `<ods-forwarding-item>
        <ods-forwarding-item-info label="Bund für Umwelt und Naturschutz Kreisgruppe Kiel" address="Kaiserstraße 25, 12443 Kiel" />
      </ods-forwarding-item>`,
  }),
};

export const WithButton: Story = {
  render: () => ({
    template: `<ods-forwarding-item>
        <ods-forwarding-item-info label="Bund für Umwelt und Naturschutz Kreisgruppe Kiel" address="Kaiserstraße 25, 12443 Kiel" />
        <ods-button variant="outline" text="Stelle ändern" end-content />
      </ods-forwarding-item>`,
  }),
};

export const WithCreationInfo: Story = {
  args: {
    direction: ForwardingDirection.FROM,
  },
  render: (args: ForwardingItemComponent) => ({
    props: args,
    template: `<ods-forwarding-item ${argsToTemplate(args)}>
        <ods-forwarding-item-info label="Bund für Umwelt und Naturschutz Kreisgruppe Kiel" address="Kaiserstraße 25, 12443 Kiel" />
        <div end-content>
          <p>20. Dez. 09:35</p>
          <p class="text-sm">Karin Wanowski-Müller</p>
        </div>
      </ods-forwarding-item>`,
  }),
};
