/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { Mock, mock, useFromMock } from '@alfa-client/test-utils';
import { Store } from '@ngrx/store';
import { Subject } from 'rxjs';
import { UserProfileFacade } from './user-profile.facade';

import * as UserProfileActions from './user-profile.actions';
import * as UserProfileSelectors from './user-profile.selectors';

describe('UserProfileFacade', () => {
  let facade: UserProfileFacade;
  let store: Mock<Store>;

  let selectionSubject: Subject<any>;

  beforeEach(() => {
    store = mock(Store);

    selectionSubject = new Subject();

    store.select.mockReturnValue(selectionSubject);

    facade = new UserProfileFacade(useFromMock(<any>store));
  });

  it('is initialized', () => {
    expect(facade).toBeTruthy();
  });

  describe('getUserProfileSearchVisibility', () => {
    it('should select from store', () => {
      facade.getUserProfileSearchVisibility();

      expect(store.select).toHaveBeenCalledWith(UserProfileSelectors.userProfileSearchVisibilty);
    });
  });

  describe('showUserProfileSearch', () => {
    it('should dispatch action', () => {
      facade.showUserProfileSearch();

      expect(store.dispatch).toHaveBeenCalledWith(UserProfileActions.showUserProfileSearch());
    });
  });

  describe('hideUserProfileSearch', () => {
    it('should dispatch action', () => {
      facade.hideUserProfileSearch();

      expect(store.dispatch).toHaveBeenCalledWith(UserProfileActions.hideUserProfileSearch());
    });
  });
});
