/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { Mock, mock } from '@alfa-client/test-utils';
import { VorgangListService, VorgangView } from '@alfa-client/vorgang-shared';
import { MockComponent } from 'ng-mocks';
import { VorgangViewItemContainerComponent } from './vorgang-view-item-container.component';
import { VorgangViewItemComponent } from './vorgang-view-item/vorgang-view-item.component';

describe('VorgangViewItemContainerComponent', () => {
  let component: VorgangViewItemContainerComponent;
  let fixture: ComponentFixture<VorgangViewItemContainerComponent>;

  const label: string = 'TestLabel';
  const view: VorgangView = VorgangView.NEU;
  const count: number = 1;

  const vorgangListService: Mock<VorgangListService> = mock(VorgangListService);

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [VorgangViewItemContainerComponent, MockComponent(VorgangViewItemComponent)],
      providers: [
        {
          provide: VorgangListService,
          useValue: vorgangListService,
        },
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(VorgangViewItemContainerComponent);
    component = fixture.componentInstance;
    component.label = label;
    component.view = view;
    component.count = count;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('ngOnInit', () => {
    it('should call service to check if view is selected', () => {
      component.ngOnInit();

      expect(vorgangListService.isVorgangViewSelected).toHaveBeenCalledWith(view);
    });

    it('should call service to get view route path', () => {
      component.ngOnInit();

      expect(vorgangListService.getVorgangViewRoutePath).toHaveBeenCalledWith(view);
    });
  });
});
