/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { createStateResource, HasLinkPipe } from '@alfa-client/tech-shared';
import { getElementFromFixture, mock } from '@alfa-client/test-utils';
import { VorgangHeaderLinkRel, VorgangWithEingangResource } from '@alfa-client/vorgang-shared';
import { WiedervorlageService } from '@alfa-client/wiedervorlage-shared';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { createVorgangWithEingangResource } from 'libs/vorgang-shared/test/vorgang';
import { createWiedervorlageListResource } from 'libs/wiedervorlage-shared/test/wiedervorlage';
import { MockComponent } from 'ng-mocks';
import { of } from 'rxjs';
import { WiedervorlageCreateButtonComponent } from '../wiedervorlage-list-in-vorgang-container/wiedervorlage-list-in-vorgang/wiedervorlage-create-button/wiedervorlage-create-button.component';
import { CreateWiedervorlageButtonContainerComponent } from './create-wiedervorlage-button-container.component';

describe('CreateWiedervorlageButtonContainerComponent', () => {
  let component: CreateWiedervorlageButtonContainerComponent;
  let fixture: ComponentFixture<CreateWiedervorlageButtonContainerComponent>;

  const wiedervorlageServie = mock(WiedervorlageService);

  const wiedervorlageCreateButton: string = getDataTestIdOf('wiedervorlage-create-button');

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        HasLinkPipe,
        CreateWiedervorlageButtonContainerComponent,
        MockComponent(WiedervorlageCreateButtonComponent),
      ],
      providers: [
        {
          provide: WiedervorlageService,
          useValue: wiedervorlageServie,
        },
      ],
    });
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(CreateWiedervorlageButtonContainerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('wiedervorlage create button', () => {
    it('should show if link exists', () => {
      component.wiedervorlageListStateResource$ = of(
        createStateResource(createWiedervorlageListResource()),
      );
      component.vorgang = createVorgangWithEingangResource([VorgangHeaderLinkRel.WIEDERVORLAGEN]);

      fixture.detectChanges();
      const element = getElementFromFixture(fixture, wiedervorlageCreateButton);

      expect(element).toBeInstanceOf(HTMLElement);
    });

    it('should hide if link does not exist', () => {
      component.vorgang = createVorgangWithEingangResource();

      fixture.detectChanges();
      const element = getElementFromFixture(fixture, wiedervorlageCreateButton);

      expect(element).not.toBeInstanceOf(HTMLElement);
    });
  });

  describe('load wiedervorlagen', () => {
    beforeEach(() => {
      wiedervorlageServie.getWiedervorlageListByGivenVorgang.mockClear();
    });

    it('should load on existing Link', () => {
      const vorgangWithEingang: VorgangWithEingangResource = createVorgangWithEingangResource([
        VorgangHeaderLinkRel.WIEDERVORLAGEN,
      ]);
      component.vorgang = vorgangWithEingang;

      component.ngOnChanges();

      expect(wiedervorlageServie.getWiedervorlageListByGivenVorgang).toHaveBeenCalledWith(
        vorgangWithEingang,
      );
    });

    it('should NOT load on missing Link', () => {
      component.vorgang = createVorgangWithEingangResource();

      component.ngOnChanges();

      expect(wiedervorlageServie.getWiedervorlageListByGivenVorgang).not.toHaveBeenCalled();
    });
  });
});
