/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { formatFullDate, replacePlaceholders } from '@alfa-client/tech-shared';
import { WiedervorlageLinkRel, WiedervorlageMessages, WiedervorlageResource } from '@alfa-client/wiedervorlage-shared';
import { Component, Input, OnInit } from '@angular/core';
import { BinaryFileListOrientation } from '../../../../../../binary-file/src/lib/directive/binary-file-list-orientation/binary-file-list-orientation.directive';

@Component({
  selector: 'alfa-wiedervorlage-in-vorgang',
  templateUrl: './wiedervorlage-in-vorgang.component.html',
  styleUrls: ['./wiedervorlage-in-vorgang.component.scss'],
})
export class WiedervorlageInVorgangComponent implements OnInit {
  @Input() wiedervorlageResource: WiedervorlageResource;

  tooltip: string;
  expanded: boolean;

  public readonly WiedervorlageLinkRel = WiedervorlageLinkRel;
  public readonly BinaryFileListOrientation = BinaryFileListOrientation;

  ngOnInit(): void {
    this.tooltip = this.formatTooltip();
  }

  formatTooltip(): string {
    const replacement = {
      betreff: this.wiedervorlageResource.betreff,
      createdAt: formatFullDate(this.wiedervorlageResource.createdAt),
    };
    return replacePlaceholders(WiedervorlageMessages.TOOLTIP, replacement);
  }

  toggle(): void {
    this.expanded = !this.expanded;
  }
}
